;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; Produce a plot of the total SFR using the sfr.txt     ;;
;; output file                                           ;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

PRO plot_totalSFR, pathn, SFR_logfile, TimeUnit, SFRUnit, smooth_time, doplotSFR


; set time =0 at pericenter
;         time_SFR = time_SFR;-tpericentr

fname_sfr = pathn+'TotalSFR'

; Read star formation logfiles 
;----------------------------------------------------------------------------------------------

         spawn,"wc "+SFR_logfile,result
         n0 = result(0)
         n0=n0
         a     = dblarr(5,n0)
         openr,1,SFR_logfile
         readf,1,a
         close,1


         time_SFR=fltarr(n0)
         Stelmass_tot=fltarr(n0)
         SFR_tot=fltarr(n0)
         SFR_tot_Msun_yr=fltarr(n0)
         Stelmass_totsum=fltarr(n0)
      

         time_SFR=a(0,*)         ; star formation time
         Stelmass_tot=a(1,*)     ; stellar mass formed  
         SFR_tot=a(2,*)          ; total star formation rate in gas particles 
         SFR_tot_Msun_yr=a(3,*)  ; total star formation rate in Msun/yr
         Stelmass_totsum=a(4,*)  ; stellar mass formed in star particles

;do conversion to physical units here
         time_SFR = time_SFR * TimeUnit ;give scale and unit to SFR time
         SFR_tot_Msun_yr = SFR_tot_Msun_yr * SFRUnit ;give scale and unit to SFR
                                ;caution: we did no conversion for
                                ;Stellmass_tot, SFR_tot, and
                                ;Stelmass_totsum so far!!!


; Smooth over number of particles
;----------------------------------------------------------------------------------------------
time_SFR_smooth = dindgen(n_elements(time_SFR)/smooth_time)
SFR_tot_Msun_yr_smooth = dindgen(n_elements(SFR_tot_Msun_yr)/smooth_time)

time_SFR_tot=0.
SFR_tot_Msun_yr_tot=0.

k=0L
;do smoothing just to second-last bin
for j=0L,n_elements(time_SFR_smooth)-2L do begin
    
    for i=k,smooth_time+k-1L do begin
        time_SFR_tot=time_SFR_tot+time_SFR(i)
        SFR_tot_Msun_yr_tot=SFR_tot_Msun_yr_tot+SFR_tot_Msun_yr(i)
    endfor    
    
    k=k+smooth_time
    
    time_SFR_smooth(j)=time_SFR_tot/smooth_time  
    SFR_tot_Msun_yr_smooth(j)=SFR_tot_Msun_yr_tot/smooth_time 
    
    time_SFR_tot=0.
    SFR_tot_Msun_yr_tot=0.
;    print, 'j, k, last time_SFR ', j,k,time_SFR(k)
endfor

;continue with last larger bin
j=n_elements(time_SFR_smooth)-1L
inorm=0L
for i=k, n_elements(time_SFR)-1L do begin
    time_SFR_tot=time_SFR_tot+time_SFR(i)
    SFR_tot_Msun_yr_tot=SFR_tot_Msun_yr_tot+SFR_tot_Msun_yr(i)
    inorm=inorm+1
endfor
time_SFR_smooth(j)=time_SFR_tot/inorm 
SFR_tot_Msun_yr_smooth(j)=SFR_tot_Msun_yr_tot/inorm

;plot
if doplotSFR eq 3 then begin
   set_plot, 'ps'
   device,  xsize=16., ysize=8.0, filename=fname_sfr+'.eps',/color,bits=8,/Encapsulated
   !p.charsize=1.
   !x.margin=[10,3]
   ;plotsym,0,/fill
   !p.thick=3
endif else begin
   set_plot, 'x'
   !p.charsize=1.
   window,29,xsize=500,ysize=500
   wset,29
endelse

 plotsym,0,/fill
 loadct,39
 !p.multi=[0,1,1]
 !x.style=1
 !y.style=1

 xtit='!N!6Time !N [Gyr]'
 ytit='!N!6 SFR!N!6 [M!D!9n!6!N/yr]'

 !x.title=xtit
 !y.title=ytit

 xminSFR = 0
 xmaxSFR = max(time_SFR_smooth)
 ymaxSFR = max(SFR_tot_Msun_yr_smooth) + 25.
 yminSFR = 10.d0^(floor(alog10(min(SFR_tot_Msun_yr_smooth))))
 yminSFR = min([yminSFR,0.1])
 print, 'Ranges for time and maxSFR: ', xminSFR, xmaxSFR, yminSFR, ymaxSFR
; icSF = where(time_SFR_smooth le xmaxSFR)

  plot,time_SFR_smooth, SFR_tot_Msun_yr_smooth,/ylog,xr=[xminSFR,xmaxSFR],yr=[yminSFR,ymaxSFR]
;  oplot,time_SFR_smooth(icSF), SFR_tot_Msun_yr_smooth(icSF),linestyle=5

if doplotSFR ge 3 then begin 
   device,/close
   set_plot, 'x'
endif
if doplotSFR eq 2 then write_png,fname_sfr+".png",TVRD(/true)


return
end
